# HorNets: Learning from Discrete and Continuous Signals with Routing Neural Networks

![build](https://github.com/bkolosk1/hornets/actions/workflows/python-install.yml/badge.svg)  ![lint](https://github.com/bkolosk1/hornets/actions/workflows/lint.yml/badge.svg) ![test](https://github.com/bkolosk1/hornets/actions/workflows/pytest.yml/badge.svg)



**HorNets** is a Python package implementing the HorNets architecture of the ``HorNets: Learning from Discrete and Continuous Signals with Routing Neural Networks`` paper.

## Installation

Follow the instructions below to install **HorNets** using your preferred method.

### Using PyPI ``stable version``

You can install **HorNets** directly from PyPI using `pip`. This is the simplest method if you just want to use the package.

```bash
pip install hornets
```

### Using PyPI ``latest version``

```bash
pip install git+git@github.com:bkolosk1/hornets.git
```

## Local Development Installation

1. Install Poetry: `pip install poetry`  
2. Clone the repo: `git clone git@github.com:bkolosk1/hornets.git && cd hornets`  
3. Run: `poetry install`
4. Test the installation with: `poetry run python examples/examples.py`


## Usage


You can run `examples/example.py` 



## Citation



Cite this work as:

```
XXXX 
```
